from django.db import models
from django.core.validators import RegexValidator,EmailValidator

# Create your models here.

class Passenger(models.Model):
    P_ID = models.AutoField(primary_key=True, editable=False, unique=True)
    First_Name = models.CharField(max_length=50)
    Middle_Initial = models.CharField(max_length=50)
    Last_Name = models.CharField(max_length = 50)
    Birthdate = models.DateField
    Age = models.CharField(max_length=3)
    male = 'Male'
    female = 'Female'
    na = 'Prefer not to say'
    gender_choices = [
        (male, 'Male'),
        (female, 'Female'),
        (na, 'Prefer not to say'),
    ]
    Gender = models.CharField(
        max_length=20,
        choices=gender_choices,
        default=na,
        )

    Phone_num = models.CharField(max_length = 7, validators=[RegexValidator(r'^\d{0,9}$',message = "Please input numbers only")])
    Email_add = models.EmailField(max_length = 254, validators=[EmailValidator()])
    
class Booking(models.Model):
    Booking_ID = models.AutoField(primary_key=True, editable=False, unique=True)
    Booking_Date = models.DateField
    Total_Cost = models.CharField(max_length=100)
    P_ID = models.ForeignKey(Passenger, on_delete=models.CASCADE)

class Flight(models.Model):
    Flight_ID = models.AutoField(primary_key=True, editable=False, unique=True)
    Flight_Code = models.CharField(max_length=5)
    Origin_Airport = models.CharField(max_length=100)
    Destination_Airport = models.CharField(max_length=100)

class Schedule(models.Model):
    Sched_Code = models.AutoField(primary_key=True, editable=False, unique=True)
    Flight_Date = models.DateField
    Departure_Time = models.TimeField
    Arrival_Time = models.TimeField
    Duration = models.CharField(max_length=50)
    Flight_Cost = models.CharField(max_length=50)
    Flight_Code = models.ForeignKey(Flight, on_delete=models.CASCADE)

class Booking_Sched(models.Model):
    class Meta:
        unique_together = ('Booking_ID', 'Sched_Code')

    Booking_ID = models.ForeignKey(Booking, on_delete=models.CASCADE)
    Sched_Code = models.ForeignKey(Schedule, on_delete=models.CASCADE)

class Additional_Item(models.Model):
    Description = models.CharField(max_length=50, primary_key=True, editable=False, unique=True)
    Item_Cost = models.IntegerField(default=0)

class Booking_AddItem(models.Model):
    class Meta:
        unique_together = ('Booking_ID', 'AddItem_Desc')

    Booking_ID = models.ForeignKey(Booking, on_delete=models.CASCADE)
    AddItem_Desc = models.ForeignKey(Additional_Item, on_delete=models.CASCADE)
    Quantity = models.IntegerField(default=0)

class City(models.Model):
    Airport_Code = models.AutoField(primary_key=True, editable=False, unique=True)
    Airport_name = models.CharField(max_length=50)
    City_Name = models.CharField(max_length=50)
    Country = models.CharField(max_length=50)

class Crew_Member(models.Model):
    Employee_ID = models.AutoField(primary_key=True, editable=False, unique=True)
    First_Name = models.CharField(max_length=50)
    Last_Name = models.CharField(max_length=50)

    pilot = 'Pilot'
    flight_attendant = 'Flight Attendant'
    role_choices = [
        (pilot, 'Pilot'),
        (flight_attendant, 'Flight Attendant')
    ]

    Role = models.CharField(max_length=50, choices=role_choices)

class Sched_Crew(models.Model):
    class Meta:
        unique_together = ('Sched_Code', 'Employee_ID')

    Sched_Code = models.ForeignKey(Schedule, on_delete=models.CASCADE)
    Employee_ID = models.ForeignKey(Crew_Member, on_delete=models.CASCADE)

class Pilot(models.Model):
    Employee_ID = models.OneToOneField(Crew_Member, on_delete=models.CASCADE, primary_key=True)
    cadet_pilot = 'Cadet Pilot'
    second_officer = 'Second Officer'
    first_officer = 'First Officer'
    senior_firstofficer = 'Senior First Officer'
    captain = 'Captain'
    rank_choices = [
        (cadet_pilot, 'Cadet Pilot'),
        (second_officer, 'Second Officer'),
        (first_officer, 'First Officer'),
        (senior_firstofficer, 'Senior First Officer'),
        (captain, 'Captain')
        ]
    Rank = models.CharField(max_length=50, choices=rank_choices)

class Flight_Attendant(models.Model):
    Employee_ID = models.OneToOneField(Crew_Member, on_delete=models.CASCADE, primary_key=True)
    economy = 'Economy'
    premium_economy = 'Premium Economy'
    business = 'Business'
    first_class = 'First Class'
    class_choices = [
        (economy, 'Economy'),
        (premium_economy, 'Premium Economy'),
        (business, 'Business'),
        (first_class, 'First Class')
    ]
    Assigned_Class = models.CharField(max_length=50, choices=class_choices)
